+++
title = "Replace only \"categories\" key"
tags = ["front-matter", "keys", "replace", "categories"]
cats = ["test-cat-x"]
draft = false
+++

This post will have the `categories` key in front-matter replaced with
`cats`.
